@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
 
 /*
  *   Gnome Nibbles: Gnome Worm Game
@@ -297,8 +297,6 @@ gnibbles_board_level_new (GnibblesBoard *board, gint level)
             gnibbles_worm_set_start (worms[count++], j, i, WORMRIGHT);
           break;
         case 'Q':
-          gnibbles_warpmanager_add_warp (warpmanager, j - 1, i - 1, -1, -1);
-          break;
         case 'R':
         case 'S':
         case 'T':
@@ -359,9 +357,7 @@ gnibbles_board_level_add_bonus (GnibblesBoard *board, gint regular)
 {
   gint x, y, good;
 
-  if (regular) {
-    good = 0;
-  } else {
+  if (!regular) {
     good = rand () % 50;
     if (good)
       return;
@@ -444,3 +440,23 @@ gnibbles_board_level_add_bonus (GnibblesBoard *board, gint regular)
     }
   }
 }
+
+/* Gasp, it's an invariant. The count of the worm's segments
+ * found on the board needs to equal its length. Or else bad. */
+gint
+gnibbles_board_count_worm_segments_for_worm (GnibblesBoard *board, GnibblesWorm *worm) {
+  gint i, j;
+  gint count = 0;
+
+  for (i = 0; i < BOARDHEIGHT; i++) {
+    for (j = 0; j < BOARDWIDTH; j++) {
+      if (board->walls[j][i] == worm->number + WORMCHAR)
+        count++;
+    }
+  }
+
+  if (count > 0)
+    g_assert_cmpint (count, ==, worm->length);
+
+  return count;
+}
