@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
 
 /*
  *   Gnome Nibbles: Gnome Worm Game
@@ -273,7 +273,6 @@ gnibbles_worm_reverse (gpointer data)
   tmp = worm->yhead;
   worm->yhead = worm->ytail;
   worm->ytail = tmp;
-  tmp = worm->yhead;
 
   if (old_dir == WORMRIGHT)
     worm->direction = WORMLEFT;
@@ -376,31 +375,32 @@ gnibbles_worm_move_head_pointer (GnibblesWorm *worm)
   switch (worm->direction) {
     case WORMRIGHT:
       worm->xhead++;
+      if (worm->xhead >= BOARDWIDTH)
+        worm->xhead = 0;
       break;
     case WORMDOWN:
       worm->yhead++;
+      if (worm->yhead >= BOARDHEIGHT)
+        worm->yhead = 0;
       break;
     case WORMLEFT:
       worm->xhead--;
+      if (worm->xhead < 0)
+        worm->xhead = BOARDWIDTH - 1;
       break;
     case WORMUP:
       worm->yhead--;
+      if (worm->yhead < 0)
+        worm->yhead = BOARDHEIGHT - 1;
       break;
     default:
-      break;
+      g_assert_not_reached ();
   }
 
-  if (worm->xhead <= 0)
-    worm->xhead = BOARDWIDTH - 1;
-  if (worm->yhead <= 0)
-    worm->yhead = BOARDHEIGHT - 1;
-  if (worm->xhead >= BOARDWIDTH)
-    worm->xhead = 0;
-  if (worm->yhead >= BOARDHEIGHT)
-    worm->yhead = 0;
-
   gnibbles_worm_handle_bonus (worm);
   gnibbles_worm_add_actor (worm);
+
+  g_assert_cmpint (board->walls[worm->xhead][worm->yhead], ==, worm->number + WORMCHAR);
 }
 
 static void
@@ -412,51 +412,35 @@ gnibbles_worm_move_tail_pointer (GnibblesWorm *worm)
   switch (tail_dir) {
     case WORMRIGHT:
       worm->xtail++;
+      if (worm->xtail >= BOARDWIDTH)
+        worm->xtail = 0;
       break;
     case WORMDOWN:
       worm->ytail++;
+      if (worm->ytail >= BOARDHEIGHT)
+        worm->ytail = 0;
       break;
     case WORMLEFT:
       worm->xtail--;
+      if (worm->xtail < 0)
+        worm->xtail = BOARDWIDTH - 1;
       break;
     case WORMUP:
       worm->ytail--;
+      if (worm->ytail < 0)
+        worm->ytail = BOARDHEIGHT - 1;
       break;
     default:
+      /* OK, we're teleporting */
       break;
   }
 
-  if (worm->xtail <= 0)
-    worm->xtail = BOARDWIDTH - 1;
-  if (worm->ytail <= 0)
-    worm->ytail = BOARDHEIGHT - 1;
-  if (worm->xtail >= BOARDWIDTH)
-    worm->xtail = 0;
-  if (worm->ytail >= BOARDHEIGHT)
-    worm->ytail = 0;
-
-  if (board->walls[worm->xtail][worm->ytail] == WARPLETTER) {
+  if (tail_dir == -1) {
     gnibbles_warpmanager_worm_change_tail_pos (warpmanager, worm);
-    tail_dir = gnibbles_worm_get_tail_direction (worm);
-    board->walls[worm->xtail][worm->ytail] = EMPTYCHAR;
-    switch (tail_dir) {
-      case WORMRIGHT:
-        worm->xtail++;
-        break;
-      case WORMDOWN:
-        worm->ytail++;
-        break;
-      case WORMLEFT:
-        worm->xtail--;
-        break;
-      case WORMUP:
-        worm->ytail--;
-        break;
-      default:
-        break;
-      }
+    board->walls[worm->xtail][worm->ytail] = worm->number + WORMCHAR;
   }
 
+  g_assert_cmpint (board->walls[worm->xtail][worm->ytail], ==, worm->number + WORMCHAR);
 }
 
 static void
@@ -674,7 +658,7 @@ gnibbles_worm_move_head (GnibblesWorm *worm)
 void
 gnibbles_worm_move_tail (GnibblesWorm *worm)
 {
-  if (g_list_length (worm->list) <= 1)
+  if (g_list_length (worm->list) < 1)
     return;
 
   if (worm->change <= 0) {
@@ -755,26 +739,27 @@ gnibbles_worm_position_move_head (GnibblesWorm * worm, gint *x, gint *y)
   switch (worm->direction) {
     case WORMUP:
       *y = worm->yhead - 1;
+      if (*y < 0)
+        *y = BOARDHEIGHT - 1;
       break;
     case WORMDOWN:
       *y = worm->yhead + 1;
+      if (*y == BOARDHEIGHT)
+        *y = 0;
       break;
     case WORMLEFT:
       *x = worm->xhead - 1;
+      if (*x < 0)
+        *x = BOARDWIDTH - 1;
       break;
     case WORMRIGHT:
       *x = worm->xhead + 1;
+      if (*x == BOARDWIDTH)
+        *x = 0;
       break;
+    default:
+      g_assert_not_reached ();
   }
-
-  if (*x == BOARDWIDTH)
-    *x = 0;
-  if (*x < 0)
-    *x = BOARDWIDTH - 1;
-  if (*y == BOARDHEIGHT)
-    *y = 0;
-  if (*y < 0)
-    *y = BOARDHEIGHT - 1;
 }
 
 gboolean
